@@ -1,5 +1,5 @@
 #
-# $Id: o2sms.pm 205 2006-03-17 16:05:58Z mackers $
+# $Id: o2sms.pm 217 2006-04-19 12:57:30Z mackers $
 
 package WWW::SMS::IE::o2sms;
 
@@ -36,7 +36,7 @@ For more information see L<WWW::SMS::IE::iesms>
 use strict;
 use warnings;
 use vars qw( $VERSION );
-$VERSION = sprintf("0.%02d", q$Revision: 205 $ =~ /(\d+)/);
+$VERSION = sprintf("0.%02d", q$Revision: 217 $ =~ /(\d+)/);
 
 @WWW::SMS::IE::o2sms::ISA = qw{WWW::SMS::IE::iesms};
 
@@ -68,11 +68,23 @@ sub _init
 
 	$self->full_name("O2 Ireland");
 	$self->domain_name("o2.ie");
-	$self->config_dir($self->_get_home_dir() . "/.o2sms/");
-	$self->config_file($self->config_dir() . "config");
-	$self->message_file($self->config_dir() . "lastmsg");
-	$self->cookie_file($self->config_dir() . ".cookie");
-	$self->action_state_file($self->config_dir() . ".state");
+
+	if ($self->is_win32())
+	{
+		$self->config_dir($self->_get_home_dir());
+		$self->config_file($self->config_dir() . "o2sms.ini");
+		$self->message_file($ENV{TMP} . "/o2sms_lastmsg.txt");
+		$self->cookie_file($ENV{TMP} . "/o2sms.cookie");
+		$self->action_state_file($ENV{TMP} . "/o2sms.state");
+	}
+	else
+	{
+		$self->config_dir($self->_get_home_dir() . "/.o2sms/");
+		$self->config_file($self->config_dir() . "config");
+		$self->message_file($self->config_dir() . "lastmsg");
+		$self->cookie_file($self->config_dir() . ".cookie");
+		$self->action_state_file($self->config_dir() . ".state");
+	}
 }
 
 sub _format_number
